133 STAT. 1032

PUBLIC LAW 116-30-JULY 25, 2019

Public Law 116-30 116th Congress

July 25, 2019

[H.R. 866]

Fairness For Breastfeeding Mothers Act of 2019. 40 USC 101 note.

40 USC 3318.

## An Act

To provide a lactation room in public buildings.

Be it enacted by the Senate and House of Representatives of the United States of America in Congress assembled,

## SECTION 1. SHORT TITLE.

This Act may be cited as the "Fairness For Breastfeeding Mothers Act of 2019".

## SEC. 2. LACTATION ROOM IN PUBLIC BUILDINGS.

(a) LACTATION ROOM IN PUBLIC BUILDINGS.-Chapter 33 of title 40, United States Code, is amended by adding at the end the following new section:

## " § 3318. Lactation room in public buildings

"(a) DEFINITIONS.-In this section:

"(1) APPROPRIATE AUTHORITY.-The term 'appropriate authority' means the head of a Federal agency, the Architect of the Capitol, or other official authority responsible for the operation of a public building.

"(2) COVERED PUBLIC BUILDING.-The term 'covered public building' means a public building (as defined in section 3301) that is open to the public and contains a public restroom, and includes a building listed in section 6301 or 5101.

"(3) LACTATION ROOM.-The term 'lactation room' means a hygienic place, other than a bathroom, that-

"(A) is shielded from view;

"(B) is free from intrusion; and

"(C) contains a chair, a working surface, and, if the public building is otherwise supplied with electricity, an electrical outlet.

"(b) LACTATION ROOM REQUIRED.-Except as provided in subsection (c), the appropriate authority of a covered public building shall ensure that the building contains a lactation room that is made available for use by members of the public to express breast milk.

"(c) EXCEPTIONS.-A covered public building may be excluded from the requirement in subsection (b) at the discretion of the appropriate authority if-

"(1) the public building-

"(A) does not contain a lactation room for employees who work in the building; and

"(B) does not have a room that could be repurposed as a lactation room or a space that could be made private using portable materials, at a reasonable cost; or